Changelog
=========

1.0.1 (2022-06-13)
------------------

- `FromROI.convert_roi_object` now also adds `label`, `score`, `minrect_w` and `minrect_h` to the
  meta-data of a `LocatedObject` instance.


1.0.0 (2021-05-20)
------------------

- Initial release after separation from wai.annotations main repo.
